==> smasindia_11_9_2025.zip: smasindia/resources/views/front/global-company.blade.php <==
@extends('front.layouts.masterhome')

@section('meta_title', 'Global Vehicle Leasing Solutions | SMAS India')
@section('meta_description', 'Explore SMAS Indias global presence and vehicle leasing expertise. Offering seamless leasing solutions across India and internationally. Learn more now!')


@section('section')
<div class="no-bottom no-top" id="content">
    <div id="top"></div>

    <!-- section begin -->
    <section id="subheader" class="jarallax text-light">
        <img src="{{ asset('front') }}/images/background/global-banner.jpg" class=" jarallax-img" alt="Global Banner">
        <div class="center-y relative text-center">
            <div class="container">
                <div class="row">
                    <div class="col-md-12 text-center">
                        <h1>Global Presence</h1>
                    </div>
                    <div class="clearfix"></div>
                </div>
            </div>
        </div>
    </section>
    <!-- section close -->

    <section class="global" id="section-global">
        <div class="container-fluid">
            <div class="row">
                <div class="col-lg-6 col-12">
                    <h2 class="mb-3">Sumitomo Mitsui Auto Service Company, Japan</h2>
                    <p>As a leading company in the auto leasing industry, SMAS Japan aims to contribute to the
                        development of the automobile
                        society and the improvement of the global environment by becoming a "mobility platform
                        provider for a sustainable
                        society.</p>
                    <p>SMAS Japan will create a sustainable future through our "comprehensive mobility services"
                        that meet all needs related to
                        the movement of people and goods.</p>
                    <!-- <p>Since its establishment in 1981, Sumitomo Mitsui Auto Service
                        has
                        gone beyond vehicle
                        leasing services. Today it
                        provides a Total vehicle management solution (TVMS) to its customers. We specialize in
                        end-to-end vehicle management
                        services covering all aspects of vehicle management.
                    </p>
                    <p>Sumitomo Mitsui Auto Services has a history of combining the three complementary business
                        of its shareholders:
                    </p>
                    <div class="global_shareholders_lists">
                        <ul>
                            <li><strong>Sumitomo Corporation</strong><b>: </b>A&nbsp;trading company
                                specializing in products and diverse
                                businesses</li>
                            <li><strong>Sumitomo Mitsui Financial Group</strong><b>:</b> A banking company
                                specializing in finance</li>
                            <li><strong>Sumitomo Mitsui Finance &amp; Leasing: </strong>The Company provides
                                equipment leasing and
                                instalment sales for manufacturing, finance, wholesale, public, and medical
                                sectors. It also offers loans,
                                real estate leasing, and other financial services.</li>
                        </ul>
                    </div>
                    <p>Sumitomo Mitsui Auto Service comes with a rich track record and years of experience
                        together as a group.</p> -->
                    <a href="http://www.smauto.co.jp/en/" class="th-btn" tabindex="0" target="_blank">Read
                        More</a>

                </div>
                <div class="col-lg-6 col-12">
                    <img src="{{ asset('front') }}/./images/global1.jpg" alt="Service, Maintenance & Repair" class="img-fluid">
                </div>
            </div>
        </div>
    </section>


    <section class="companies" id="companies-section">
        <div class="position-fix">
            <div class="bg"></div>
            <div class="bg bg2"></div>
            <div class="bg bg3"></div>
        </div>
        <div class="container-fluid">
            <div class="row align-items-center  justify-content-center">
                <div class="col-lg-12 text-center">
                    <h2>Overseas</h2>
                    <div class="spacer-20"></div>
                </div>
                <div class="col-lg-10">
                    <div class="box-map map position-relative">
                        <img src="{{ asset('front') }}/./images/map-asia4-1.jpg" alt=""
                            class="img-fluid asia position-relative">
                        <div class="point india tippy" title="India"></div>
                        <div class="point thailand tippy" title="Thailand"></div>
                        <div class="point indonesia tippy" title="Indonesia"></div>
                        <div class="point australia tippy" title="Australia"></div>
                    </div>

                </div>

                <div class="col-lg-12 col-12">
                    <h3 class="project-title"> <a href="#" tabindex="0">Sumitomo Mitsui
                            Auto Leasing
                            & Service (Thailand) Co., Ltd.</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>March 18, 2003</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>THB 240.5 million</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Bangkok, Thailand</td>
                                </tr>
                            </tbody>
                        </table>

                        <p><a class="btn btn_submitour mt-3 py-3" href="https://smauto.co.th/"
                                target="_blank">Sumitomo
                                Mitsui Auto Leasing & Service (Thailand) Co., Ltd. <img
                                    src="{{ asset('front') }}/images/external-link.png" class="img-fluid icon-01"
                                    alt=""></a></p>
                    </div>
                </div>

                <div class="col-lg-12 col-12 mt-3">
                    <h3 class="project-title"> <a href="#" tabindex="0">Summit Auto
                            Lease Australia Pty Ltd.</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>December 20, 1996</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>AUD 32 million</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Sydney (head office), Melbourne, Brisbane and Perth (sales offices),
                                        Australia</td>
                                </tr>
                            </tbody>
                        </table>

                        <p><a class="btn btn_submitour mt-3 py-3" href="https://www.summitfleet.com.au/"
                                target="_blank">Summit Auto Lease
                                Australia Pty Ltd. <img src="{{ asset('front') }}/images/external-link.png"
                                    class="img-fluid icon-01" alt=""></a></p>
                    </div>
                </div>

                <div class="col-lg-12 col-12 mt-3">
                    <h3 class="project-title"> <a href="#" tabindex="0">PT SMAS Mobility
                            Indonesia</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>September 5, 2023（Ministry Approval）</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>IDR 245 billion</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Jakarta, Indonesia</td>
                                </tr>
                            </tbody>
                        </table>
                        <p><a class="btn btn_submitour mt-3 py-3" href="https://www.smasmobility.co.id/"
                                target="_blank">PT
                                SMAS Mobility Indonesia <img src="{{ asset('front') }}/images/external-link.png"
                                    class="img-fluid icon-01" alt=""></a></p>

                    </div>
                </div>
            </div>
        </div>
    </section>


</div>
@endsection

==> smasindia_26_10_2025.zip: smasindia/resources/views/front/global-company.blade.php <==
@extends('front.layouts.masterhome')

@section('meta_title', 'Global Vehicle Leasing Solutions | SMAS India')
@section('meta_description', 'Explore SMAS Indias global presence and vehicle leasing expertise. Offering seamless leasing solutions across India and internationally. Learn more now!')


@section('section')
<div class="no-bottom no-top" id="content">
    <div id="top"></div>

    <!-- section begin -->
    <section id="subheader" class="jarallax text-light">
        <img src="{{ secure_asset('front') }}/images/background/global-banner.jpg" class=" jarallax-img" alt="Global Banner">
        <div class="center-y relative text-center">
            <div class="container">
                <div class="row">
                    <div class="col-md-12 text-center">
                        <h1>Global Presence</h1>
                    </div>
                    <div class="clearfix"></div>
                </div>
            </div>
        </div>
    </section>
    <!-- section close -->

    <section class="global" id="section-global">
        <div class="container-fluid">
            <div class="row">
                <div class="col-lg-6 col-12">
                    <h2 class="mb-3">Sumitomo Mitsui Auto Service Company, Japan</h2>
                    <p>As a leading company in the auto leasing industry, SMAS Japan aims to contribute to the
                        development of the automobile
                        society and the improvement of the global environment by becoming a "mobility platform
                        provider for a sustainable
                        society.</p>
                    <p>SMAS Japan will create a sustainable future through our "comprehensive mobility services"
                        that meet all needs related to
                        the movement of people and goods.</p>
                    <!-- <p>Since its establishment in 1981, Sumitomo Mitsui Auto Service
                        has
                        gone beyond vehicle
                        leasing services. Today it
                        provides a Total vehicle management solution (TVMS) to its customers. We specialize in
                        end-to-end vehicle management
                        services covering all aspects of vehicle management.
                    </p>
                    <p>Sumitomo Mitsui Auto Services has a history of combining the three complementary business
                        of its shareholders:
                    </p>
                    <div class="global_shareholders_lists">
                        <ul>
                            <li><strong>Sumitomo Corporation</strong><b>: </b>A&nbsp;trading company
                                specializing in products and diverse
                                businesses</li>
                            <li><strong>Sumitomo Mitsui Financial Group</strong><b>:</b> A banking company
                                specializing in finance</li>
                            <li><strong>Sumitomo Mitsui Finance &amp; Leasing: </strong>The Company provides
                                equipment leasing and
                                instalment sales for manufacturing, finance, wholesale, public, and medical
                                sectors. It also offers loans,
                                real estate leasing, and other financial services.</li>
                        </ul>
                    </div>
                    <p>Sumitomo Mitsui Auto Service comes with a rich track record and years of experience
                        together as a group.</p> -->
                    <a href="http://www.smauto.co.jp/en/" class="th-btn" tabindex="0" target="_blank">Read
                        More</a>

                </div>
                <div class="col-lg-6 col-12">
                    <img src="{{ secure_asset('front') }}/./images/global1.jpg" alt="Service, Maintenance & Repair" class="img-fluid">
                </div>
            </div>
        </div>
    </section>


    <section class="companies" id="companies-section">
        <div class="position-fix">
            <div class="bg"></div>
            <div class="bg bg2"></div>
            <div class="bg bg3"></div>
        </div>
        <div class="container-fluid">
            <div class="row align-items-center  justify-content-center">
                <div class="col-lg-12 text-center">
                    <h2>Overseas</h2>
                    <div class="spacer-20"></div>
                </div>
                <div class="col-lg-10">
                    <div class="box-map map position-relative">
                        <img src="{{ secure_asset('front') }}/./images/map-asia4-1.jpg" alt=""
                            class="img-fluid asia position-relative">
                        <div class="point india tippy" title="India"></div>
                        <div class="point thailand tippy" title="Thailand"></div>
                        <div class="point indonesia tippy" title="Indonesia"></div>
                        <div class="point australia tippy" title="Australia"></div>
                    </div>

                </div>

                <div class="col-lg-12 col-12">
                    <h3 class="project-title"> <a href="#" tabindex="0">Sumitomo Mitsui
                            Auto Leasing
                            & Service (Thailand) Co., Ltd.</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>March 18, 2003</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>THB 240.5 million</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Bangkok, Thailand</td>
                                </tr>
                            </tbody>
                        </table>

                        <p><a class="btn btn_submitour mt-3 py-3" href="https://smauto.co.th/"
                                target="_blank">Sumitomo
                                Mitsui Auto Leasing & Service (Thailand) Co., Ltd. <img
                                    src="{{ secure_asset('front') }}/images/external-link.png" class="img-fluid icon-01"
                                    alt=""></a></p>
                    </div>
                </div>

                <div class="col-lg-12 col-12 mt-3">
                    <h3 class="project-title"> <a href="#" tabindex="0">Summit Auto
                            Lease Australia Pty Ltd.</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>December 20, 1996</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>AUD 32 million</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Sydney (head office), Melbourne, Brisbane and Perth (sales offices),
                                        Australia</td>
                                </tr>
                            </tbody>
                        </table>

                        <p><a class="btn btn_submitour mt-3 py-3" href="https://www.summitfleet.com.au/"
                                target="_blank">Summit Auto Lease
                                Australia Pty Ltd. <img src="{{ secure_asset('front') }}/images/external-link.png"
                                    class="img-fluid icon-01" alt=""></a></p>
                    </div>
                </div>

                <div class="col-lg-12 col-12 mt-3">
                    <h3 class="project-title"> <a href="#" tabindex="0">PT SMAS Mobility
                            Indonesia</a></h3>
                    <div class="col-lg-8 col-12">
                        <table class="table table-hover">
                            <tbody>
                                <tr>
                                    <th>Date of Establishment</th>
                                    <td>September 5, 2023（Ministry Approval）</td>
                                </tr>
                                <tr>
                                    <th>Capital</th>
                                    <td>IDR 245 billion</td>
                                </tr>
                                <tr>
                                    <th>Office Location(s)</th>
                                    <td>Jakarta, Indonesia</td>
                                </tr>
                            </tbody>
                        </table>
                        <p><a class="btn btn_submitour mt-3 py-3" href="https://www.smasmobility.co.id/"
                                target="_blank">PT
                                SMAS Mobility Indonesia <img src="{{ secure_asset('front') }}/images/external-link.png"
                                    class="img-fluid icon-01" alt=""></a></p>

                    </div>
                </div>
            </div>
        </div>
    </section>


</div>
@endsection
